@@ -150,7 +150,7 @@ def test_monte_carlo_comparison():
         y_samples = numpy.random.normal(y.nominal_value, y.std_dev,
                                         n_samples)
 
-        # !!! astype() is a temporary fix for NumPy 1.8:        
+        # !! astype() is a fix for median() in NumPy 1.8.0:
         function_samples = function(x_samples, y_samples).astype(float)
 
         cov_mat = numpy.cov([x_samples, y_samples], function_samples)
@@ -207,21 +207,6 @@ def test_math_module():
     # Regular operations are chosen to be unchanged:
     assert isinstance(umath.sin(3), float)
 
-    # Python >=2.6 functions:
-
-    if sys.version_info >= (2, 6):
-    
-        # factorial() must not be "damaged" by the umath module, so as 
-        # to help make it a drop-in replacement for math (even though 
-        # factorial() does not work on numbers with uncertainties 
-        # because it is restricted to integers, as for 
-        # math.factorial()):
-        assert umath.factorial(4) == 24
-
-        # fsum is special because it does not take a fixed number of
-        # variables:
-        assert umath.fsum([x, x]).nominal_value == -3
-
     # Functions that give locally constant results are tested: they
     # should give the same result as their float equivalent:
     for name in umath.locally_cst_funcs:
@@ -244,62 +229,30 @@ def test_math_module():
     ## surprisingly catches OverflowError. So, tests are written in a
     ## version-specific manner (until the Nose issue is resolved).
 
-    if sys.version_info < (2, 6):
-            
-        try:
-            math.log(0)
-        except OverflowError, err_math:  # "as", for Python 2.6+
-            pass
-        else:
-            raise Exception('OverflowError exception expected')
-        try:
-            umath.log(0)
-        except OverflowError, err_ufloat:  # "as", for Python 2.6+
-            assert err_math.args == err_ufloat.args
-        else:
-            raise Exception('OverflowError exception expected')
-        try:
-            umath.log(ufloat(0, 0))
-        except OverflowError, err_ufloat:  # "as", for Python 2.6+
-            assert err_math.args == err_ufloat.args
-        else:
-            raise Exception('OverflowError exception expected')
-        try:
-            umath.log(ufloat(0, 1))
-        except OverflowError, err_ufloat:  # "as", for Python 2.6+
-            assert err_math.args == err_ufloat.args
-        else:
-            raise Exception('OverflowError exception expected')
-
+    try:
+        math.log(0)
+    except OverflowError, err_math:  # "as", for Python 2.6+
+        pass
     else:
-
-        try:
-            math.log(0)
-        except ValueError, err_math:  # Python 2.6+: as err_math
-            # Python 3 does not make exceptions local variables: they are
-            # restricted to their except block:
-            err_math_args = err_math.args
-        else:
-            raise Exception('ValueError exception expected')
-
-        try:
-            umath.log(0)
-        except ValueError, err_ufloat:  # Python 2.6+: as err_math
-            assert err_math_args == err_ufloat.args
-        else:
-            raise Exception('ValueError exception expected')
-        try:
-            umath.log(ufloat(0, 0))
-        except ValueError, err_ufloat:  # Python 2.6+: as err_math
-            assert err_math_args == err_ufloat.args
-        else:
-            raise Exception('ValueError exception expected')
-        try:
-            umath.log(ufloat(0, 1))
-        except ValueError, err_ufloat:  # Python 2.6+: as err_math
-            assert err_math_args == err_ufloat.args
-        else:
-            raise Exception('ValueError exception expected')
+        raise Exception('OverflowError exception expected')
+    try:
+        umath.log(0)
+    except OverflowError, err_ufloat:  # "as", for Python 2.6+
+        assert err_math.args == err_ufloat.args
+    else:
+        raise Exception('OverflowError exception expected')
+    try:
+        umath.log(ufloat(0, 0))
+    except OverflowError, err_ufloat:  # "as", for Python 2.6+
+        assert err_math.args == err_ufloat.args
+    else:
+        raise Exception('OverflowError exception expected')
+    try:
+        umath.log(ufloat(0, 1))
+    except OverflowError, err_ufloat:  # "as", for Python 2.6+
+        assert err_math.args == err_ufloat.args
+    else:
+        raise Exception('OverflowError exception expected')
 
     
 def test_hypot():
@@ -349,10 +302,7 @@ def test_power_special_cases():
     err_msg = 'A proper exception should have been raised'
 
     # An exception must have occurred:
-    if sys.version_info >= (2, 6):
-        assert err_class == ValueError, err_msg
-    else:
-        assert err_class == OverflowError, err_msg
+    assert err_class == OverflowError, err_msg
             
     try:
         result = umath.pow(negative, positive)
@@ -364,11 +314,8 @@ def test_power_special_cases():
         # know how to calculate it.
         pass
     else:
-        if sys.version_info >= (2, 6):
-            raise Exception('A proper exception should have been raised')
-        else:
-            assert test_uncertainties.isnan(result.nominal_value)
-            assert test_uncertainties.isnan(result.std_dev)
+        assert test_uncertainties.isnan(result.nominal_value)
+        assert test_uncertainties.isnan(result.std_dev)
     
 def test_power_wrt_ref():
     '''
